==> cozy-ui-122.11.1.tgz: package/transpiled/react/SquareAppIcon/index.js <==
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
var _excluded = ["display", "name", "variant", "IconContent", "description", "hideShortcutBadge"];
import cx from 'classnames';
import get from 'lodash/get';
import PropTypes from 'prop-types';
import React, { useEffect, useState } from 'react';
import ListItemText from 'cozy-ui/transpiled/react/ListItemText';
var stylesCozy = {
  "SquareAppIcon-wrapper": "styles__SquareAppIcon-wrapper___2SEuM",
  "SquareAppIcon-icon-container": "styles__SquareAppIcon-icon-container___39MRl",
  "SquareAppIcon-wrapper-ghost": "styles__SquareAppIcon-wrapper-ghost___1ZALZ",
  "SquareAppIcon-icon-container-normal": "styles__SquareAppIcon-icon-container-normal___DCe9y",
  "SquareAppIcon-wrapper-maintenance": "styles__SquareAppIcon-wrapper-maintenance___2ne2n",
  "SquareAppIcon-wrapper-loading": "styles__SquareAppIcon-wrapper-loading___3A1_X",
  "SquareAppIcon-spinner": "styles__SquareAppIcon-spinner___o0LO1",
  "onEnd": "styles__onEnd___1O6Q7",
  "isFailed": "styles__isFailed___2AYxx",
  "isSuccess": "styles__isSuccess___I6nFq",
  "end-animation": "styles__end-animation___1O0b3"
};
var stylesTwake = {
  "SquareAppIcon-wrapper": "styles_twake__SquareAppIcon-wrapper___4P3Cx",
  "SquareAppIcon-wrapper--light": "styles_twake__SquareAppIcon-wrapper--light___3LfPB",
  "SquareAppIcon-wrapper--dark": "styles_twake__SquareAppIcon-wrapper--dark___kRx3L",
  "SquareAppIcon-icon-container": "styles_twake__SquareAppIcon-icon-container___grFij",
  "SquareAppIcon-wrapper-ghost": "styles_twake__SquareAppIcon-wrapper-ghost___3xelE",
  "SquareAppIcon-icon-container-normal": "styles_twake__SquareAppIcon-icon-container-normal___1O1bk",
  "SquareAppIcon-wrapper-maintenance": "styles_twake__SquareAppIcon-wrapper-maintenance___hoMUk",
  "SquareAppIcon-wrapper-loading": "styles_twake__SquareAppIcon-wrapper-loading___AoTRM",
  "SquareAppIcon-spinner": "styles_twake__SquareAppIcon-spinner___UOK0n",
  "onEnd": "styles_twake__onEnd___GkZzo",
  "isFailed": "styles_twake__isFailed___CO_WC",
  "isSuccess": "styles_twake__isSuccess___sH4pb",
  "end-animation": "styles_twake__end-animation___26Lyd"
};
import AppIcon from "cozy-ui/transpiled/react/AppIcon";
import Badge from "cozy-ui/transpiled/react/Badge";
import Icon from "cozy-ui/transpiled/react/Icon";
import IconCheckAnimated from "cozy-ui/transpiled/react/Icons/IconCheckAnimated";
import SvgIconCrossAnimated from "cozy-ui/transpiled/react/Icons/IconCrossAnimated";
import iconOut from "cozy-ui/transpiled/react/Icons/LinkOut";
import iconPlus from "cozy-ui/transpiled/react/Icons/Plus";
import iconWarning from "cozy-ui/transpiled/react/Icons/WarningCircle";
import InfosBadge from "cozy-ui/transpiled/react/InfosBadge";
import Spinner from "cozy-ui/transpiled/react/Spinner";
import Typography from "cozy-ui/transpiled/react/Typography";
import { isTwakeTheme } from "cozy-ui/transpiled/react/helpers/isTwakeTheme";
import { nameToColor } from "cozy-ui/transpiled/react/legacy/Avatar/helpers";
import { useBreakpoints } from "cozy-ui/transpiled/react/providers/Breakpoints";
import CozyTheme, { useCozyTheme } from "cozy-ui/transpiled/react/providers/CozyTheme";
import { alpha, makeStyles } from "cozy-ui/transpiled/react/styles";
var styles = isTwakeTheme() ? stylesTwake : stylesCozy;

var makeTwakeColor = function makeTwakeColor(theme) {
  return theme.variant === 'inverted' || theme.type === 'dark' ? 'var(--white)' : 'var(--black)';
};

var useStyles = makeStyles(function (theme) {
  return {
    name: _defineProperty({
      color: isTwakeTheme() ? makeTwakeColor(theme) : 'var(--primaryTextColor)',
      textShadow: isTwakeTheme() ? theme.variant === 'inverted' || theme.type === 'dark' ? '0px 0px 10px rgba(0, 0, 0, 0.10), 0px 0px 2px rgba(0, 0, 0, 0.20), 0.5px 0.5px 1px rgba(0, 0, 0, 0.50)' : undefined : undefined,
      width: '5.5rem',
      textAlign: 'center',
      fontSize: isTwakeTheme() ? undefined : '0.875rem',
      lineHeight: isTwakeTheme() ? undefined : '1.188rem',
      margin: '0.5rem 0.25rem 0 0.25rem',
      lineClamp: '2',
      boxOrient: 'vertical',
      display: '-webkit-box',
      height: '2.375rem'
    }, theme.breakpoints.down('sm'), {
      width: '3.75rem',
      fontSize: isTwakeTheme() ? undefined : '0.6875rem',
      lineHeight: isTwakeTheme() ? undefined : '1rem',
      margin: '0.25rem 0.25rem 0 0.25rem',
      height: '2rem'
    }),
    nameInverted: {
      textShadow: theme.textShadows[1]
    },
    squareAppIconGhost: {
      backgroundColor: alpha(theme.palette.primary.main, theme.palette.action.ghostOpacity),
      border: "1px dashed ".concat(alpha(theme.palette.primary.main, theme.palette.border.ghostOpacity))
    },
    letter: {
      color: 'white',
      margin: 'auto'
    },
    shadow: {
      boxShadow: isTwakeTheme() ? undefined : theme.shadows[1]
    },
    errorIcon: {
      fill: 'var(--errorColor)',
      backgroundColor: 'var(--primaryContrastTextColor)',
      borderRadius: '1rem'
    },
    tileWrapper: _defineProperty({
      cursor: 'pointer',
      // Whole block is clickable so we should display the pointer
      display: 'flex',
      flexDirection: 'column',
      alignItems: 'center',
      minWidth: '6rem'
    }, theme.breakpoints.down('sm'), {
      minWidth: '4.25rem'
    }),
    detailedTileWrapper: {
      flexDirection: 'row',
      width: 'auto'
    }
  };
});

var shouldRenderSpinner = function shouldRenderSpinner(variant, animationState) {
  return ['loading'].includes(variant) || animationState;
};

var SquareAppIconSpinner = function SquareAppIconSpinner(_ref) {
  var variant = _ref.variant,
      animationState = _ref.animationState;

  if (!shouldRenderSpinner(variant, animationState)) {
    return null;
  }

  return /*#__PURE__*/React.createElement(Spinner, {
    className: cx(styles['SquareAppIcon-spinner'], 'u-m-0')
  });
};

export var SquareAppIcon = function SquareAppIcon(_ref2) {
  var _cx3;

  var display = _ref2.display,
      name = _ref2.name,
      variant = _ref2.variant,
      IconContent = _ref2.IconContent,
      description = _ref2.description,
      _ref2$hideShortcutBad = _ref2.hideShortcutBadge,
      hideShortcutBadge = _ref2$hideShortcutBad === void 0 ? false : _ref2$hideShortcutBad,
      appIconProps = _objectWithoutProperties(_ref2, _excluded);

  var _useCozyTheme = useCozyTheme(),
      themeVariant = _useCozyTheme.variant,
      type = _useCozyTheme.type;

  var _useBreakpoints = useBreakpoints(),
      isMobile = _useBreakpoints.isMobile;

  var classes = useStyles();
  var appName = name || get(appIconProps, 'app.name') || get(appIconProps, 'app') || '';
  var letter = appName[0] || '';
  var prevVariant = React.useRef(variant);

  var _useState = useState(),
      _useState2 = _slicedToArray(_useState, 2),
      animationState = _useState2[0],
      setAnimationState = _useState2[1];

  var handleAnimationEnd = function handleAnimationEnd(e) {
    if (e.animationName.includes('end')) setAnimationState();
  };

  useEffect(function () {
    var curr = prevVariant.current;
    if (curr === 'loading' && variant === 'error') setAnimationState('failed');
    if (curr === 'loading' && (variant === 'default' || variant === undefined)) setAnimationState('success');
    prevVariant.current = variant;
  }, [variant]);
  var exceptionVariant = [isTwakeTheme() ? 'ghost' : 'add', 'ghost'];
  var squareTheme = exceptionVariant.includes(variant) ? themeVariant : 'normal';
  return /*#__PURE__*/React.createElement("div", {
    "data-testid": "square-app-icon",
    className: cx(classes.tileWrapper, _defineProperty({}, classes.detailedTileWrapper, display === 'detailed'))
  }, /*#__PURE__*/React.createElement(CozyTheme, {
    variant: squareTheme
  }, /*#__PURE__*/React.createElement(InfosBadge, {
    badgeContent: variant === 'shortcut' && !hideShortcutBadge ? /*#__PURE__*/React.createElement(Icon, {
      size: "10",
      icon: iconOut
    }) : null,
    className: cx(_defineProperty({}, 'u-mr-1', display === 'detailed')),
    overlap: "rectangular",
    invisible: variant !== 'shortcut' || hideShortcutBadge
  }, /*#__PURE__*/React.createElement(SquareAppIconSpinner, {
    variant: variant,
    animationState: animationState
  }), /*#__PURE__*/React.createElement(Badge, {
    className: cx(styles["SquareAppIcon-wrapper"], styles["SquareAppIcon-wrapper-".concat(variant)], styles["SquareAppIcon-wrapper--".concat(type)], (_cx3 = {}, _defineProperty(_cx3, classes.squareAppIconGhost, exceptionVariant.includes(variant)), _defineProperty(_cx3, classes.shadow, !exceptionVariant.includes(variant)), _cx3)),
    badgeContent: variant === 'error' ? /*#__PURE__*/React.createElement(Icon, {
      size: 16,
      className: cx(classes.errorIcon),
      icon: iconWarning
    }) : '',
    color: variant === 'error' ? 'error' : undefined,
    withBorder: false,
    size: "large",
    overlap: "rectangular",
    style: variant === 'shortcut' && !IconContent ? _defineProperty({}, isTwakeTheme() ? 'background' : 'backgroundColor', nameToColor(name)) : null
  }, variant === 'shortcut' && !IconContent ? /*#__PURE__*/React.createElement(Typography, {
    className: classes.letter,
    variant: "h2",
    align: "center"
  }, letter.toUpperCase()) : /*#__PURE__*/React.createElement("div", {
    className: cx(styles['SquareAppIcon-icon-container'], _defineProperty({}, styles['SquareAppIcon-icon-container-normal'], themeVariant === 'normal'))
  }, /*#__PURE__*/React.createElement("div", {
    className: cx(styles['onEnd'], _defineProperty({}, styles['isSuccess'], animationState === 'success'), _defineProperty({}, styles['isFailed'], animationState === 'failed')),
    onAnimationEnd: handleAnimationEnd
  }, animationState && /*#__PURE__*/React.createElement(Icon, {
    size: 32,
    icon: animationState === 'success' ? IconCheckAnimated : SvgIconCrossAnimated
  })), variant === 'add' ? /*#__PURE__*/React.createElement(Icon, {
    icon: iconPlus,
    color: "var(--primaryColor)"
  }) : IconContent ? IconContent : isTwakeTheme() ? /*#__PURE__*/React.createElement("div", {
    className: "u-w-1-half-s u-h-1-half-s u-w-2 u-h-2"
  }, /*#__PURE__*/React.createElement(AppIcon, appIconProps)) : /*#__PURE__*/React.createElement(AppIcon, appIconProps))))), display === 'detailed' ? /*#__PURE__*/React.createElement(ListItemText, {
    primary: appName,
    secondary: description
  }) : /*#__PURE__*/React.createElement(Typography, {
    className: cx(classes.name, _defineProperty({}, classes.nameInverted, themeVariant === 'inverted'), 'u-spacellipsis'),
    variant: isTwakeTheme() ? isMobile ? 'overline' : 'h6' : 'h6',
    align: "center"
  }, appName));
};
/**
 * Having both a `display` and a `variant` prop is a bit confusing,
 * but it's necessary since the `variant` prop can be used both in "compact" and "detailed" mode.
 *
 * As for the `description` prop, it will only be displayed in "detailed" mode.
 * Providing it in "compact" mode will have no effect.
 */

SquareAppIcon.propTypes = {
  display: PropTypes.oneOf(['compact', 'detailed']),
  description: PropTypes.string,
  name: PropTypes.string,
  variant: PropTypes.oneOf(['default', 'loading', 'ghost', 'maintenance', 'error', 'add', 'shortcut']),
  IconContent: PropTypes.node
};
SquareAppIcon.defaultProps = {
  display: 'compact',
  variant: 'default'
};
export default SquareAppIcon;

==> cozy-ui-124.0.0.tgz: package/transpiled/react/SquareAppIcon/index.js <==
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
var _excluded = ["display", "name", "variant", "IconContent", "description", "hideShortcutBadge"];
import cx from 'classnames';
import get from 'lodash/get';
import PropTypes from 'prop-types';
import React, { useEffect, useState } from 'react';
import ListItemText from 'cozy-ui/transpiled/react/ListItemText';
var styles = {
  "SquareAppIcon-wrapper": "styles__SquareAppIcon-wrapper___2SEuM",
  "SquareAppIcon-wrapper--light": "styles__SquareAppIcon-wrapper--light___2iR5Y",
  "SquareAppIcon-wrapper--dark": "styles__SquareAppIcon-wrapper--dark___1vYbb",
  "SquareAppIcon-icon-container": "styles__SquareAppIcon-icon-container___39MRl",
  "SquareAppIcon-wrapper-ghost": "styles__SquareAppIcon-wrapper-ghost___1ZALZ",
  "SquareAppIcon-icon-container-normal": "styles__SquareAppIcon-icon-container-normal___DCe9y",
  "SquareAppIcon-wrapper-maintenance": "styles__SquareAppIcon-wrapper-maintenance___2ne2n",
  "SquareAppIcon-wrapper-loading": "styles__SquareAppIcon-wrapper-loading___3A1_X",
  "SquareAppIcon-spinner": "styles__SquareAppIcon-spinner___o0LO1",
  "onEnd": "styles__onEnd___1O6Q7",
  "isFailed": "styles__isFailed___2AYxx",
  "isSuccess": "styles__isSuccess___I6nFq",
  "end-animation": "styles__end-animation___1O0b3"
};
import AppIcon from "cozy-ui/transpiled/react/AppIcon";
import Badge from "cozy-ui/transpiled/react/Badge";
import Icon from "cozy-ui/transpiled/react/Icon";
import IconCheckAnimated from "cozy-ui/transpiled/react/Icons/IconCheckAnimated";
import SvgIconCrossAnimated from "cozy-ui/transpiled/react/Icons/IconCrossAnimated";
import iconOut from "cozy-ui/transpiled/react/Icons/LinkOut";
import iconPlus from "cozy-ui/transpiled/react/Icons/Plus";
import iconWarning from "cozy-ui/transpiled/react/Icons/WarningCircle";
import InfosBadge from "cozy-ui/transpiled/react/InfosBadge";
import Spinner from "cozy-ui/transpiled/react/Spinner";
import Typography from "cozy-ui/transpiled/react/Typography";
import { nameToColor } from "cozy-ui/transpiled/react/legacy/Avatar/helpers";
import CozyTheme, { useCozyTheme } from "cozy-ui/transpiled/react/providers/CozyTheme";
import { alpha, makeStyles } from "cozy-ui/transpiled/react/styles";

var makeTwakeColor = function makeTwakeColor(theme) {
  return theme.variant === 'inverted' || theme.type === 'dark' ? 'var(--white)' : 'var(--black)';
};

var useStyles = makeStyles(function (theme) {
  return {
    name: _defineProperty({
      color: makeTwakeColor(theme),
      textShadow: theme.variant === 'inverted' || theme.type === 'dark' ? '0px 0px 10px rgba(0, 0, 0, 0.10), 0px 0px 2px rgba(0, 0, 0, 0.20), 0.5px 0.5px 1px rgba(0, 0, 0, 0.50)' : undefined,
      width: '5.5rem',
      textAlign: 'center',
      margin: '0.5rem 0.25rem 0 0.25rem',
      lineClamp: '2',
      boxOrient: 'vertical',
      display: '-webkit-box',
      height: '2.375rem'
    }, theme.breakpoints.down('sm'), {
      width: '3.75rem',
      margin: '0.25rem 0.25rem 0 0.25rem',
      height: '2rem'
    }),
    nameInverted: {
      textShadow: theme.textShadows[1]
    },
    squareAppIconGhost: {
      backgroundColor: alpha(theme.palette.primary.main, theme.palette.action.ghostOpacity),
      border: "1px dashed ".concat(alpha(theme.palette.primary.main, theme.palette.border.ghostOpacity))
    },
    letter: {
      color: 'white',
      margin: 'auto'
    },
    errorIcon: {
      fill: 'var(--errorColor)',
      backgroundColor: 'var(--primaryContrastTextColor)',
      borderRadius: '1rem'
    },
    tileWrapper: _defineProperty({
      cursor: 'pointer',
      // Whole block is clickable so we should display the pointer
      display: 'flex',
      flexDirection: 'column',
      alignItems: 'center',
      minWidth: '6rem'
    }, theme.breakpoints.down('sm'), {
      minWidth: '4.25rem'
    }),
    detailedTileWrapper: {
      flexDirection: 'row',
      width: 'auto'
    }
  };
});

var shouldRenderSpinner = function shouldRenderSpinner(variant, animationState) {
  return ['loading'].includes(variant) || animationState;
};

var SquareAppIconSpinner = function SquareAppIconSpinner(_ref) {
  var variant = _ref.variant,
      animationState = _ref.animationState;

  if (!shouldRenderSpinner(variant, animationState)) {
    return null;
  }

  return /*#__PURE__*/React.createElement(Spinner, {
    className: cx(styles['SquareAppIcon-spinner'], 'u-m-0')
  });
};

export var SquareAppIcon = function SquareAppIcon(_ref2) {
  var _cx3;

  var display = _ref2.display,
      name = _ref2.name,
      variant = _ref2.variant,
      IconContent = _ref2.IconContent,
      description = _ref2.description,
      _ref2$hideShortcutBad = _ref2.hideShortcutBadge,
      hideShortcutBadge = _ref2$hideShortcutBad === void 0 ? false : _ref2$hideShortcutBad,
      appIconProps = _objectWithoutProperties(_ref2, _excluded);

  var _useCozyTheme = useCozyTheme(),
      themeVariant = _useCozyTheme.variant,
      type = _useCozyTheme.type;

  var classes = useStyles();
  var appName = name || get(appIconProps, 'app.name') || get(appIconProps, 'app') || '';
  var letter = appName[0] || '';
  var prevVariant = React.useRef(variant);

  var _useState = useState(),
      _useState2 = _slicedToArray(_useState, 2),
      animationState = _useState2[0],
      setAnimationState = _useState2[1];

  var handleAnimationEnd = function handleAnimationEnd(e) {
    if (e.animationName.includes('end')) setAnimationState();
  };

  useEffect(function () {
    var curr = prevVariant.current;
    if (curr === 'loading' && variant === 'error') setAnimationState('failed');
    if (curr === 'loading' && (variant === 'default' || variant === undefined)) setAnimationState('success');
    prevVariant.current = variant;
  }, [variant]);
  var exceptionVariant = ['ghost'];
  var squareTheme = exceptionVariant.includes(variant) ? themeVariant : 'normal';
  return /*#__PURE__*/React.createElement("div", {
    "data-testid": "square-app-icon",
    className: cx(classes.tileWrapper, _defineProperty({}, classes.detailedTileWrapper, display === 'detailed'))
  }, /*#__PURE__*/React.createElement(CozyTheme, {
    variant: squareTheme
  }, /*#__PURE__*/React.createElement(InfosBadge, {
    badgeContent: variant === 'shortcut' && !hideShortcutBadge ? /*#__PURE__*/React.createElement(Icon, {
      size: "10",
      icon: iconOut
    }) : null,
    className: cx(_defineProperty({}, 'u-mr-1', display === 'detailed')),
    overlap: "rectangular",
    invisible: variant !== 'shortcut' || hideShortcutBadge
  }, /*#__PURE__*/React.createElement(SquareAppIconSpinner, {
    variant: variant,
    animationState: animationState
  }), /*#__PURE__*/React.createElement(Badge, {
    className: cx(styles["SquareAppIcon-wrapper"], styles["SquareAppIcon-wrapper-".concat(variant)], styles["SquareAppIcon-wrapper--".concat(type)], (_cx3 = {}, _defineProperty(_cx3, classes.squareAppIconGhost, exceptionVariant.includes(variant)), _defineProperty(_cx3, classes.shadow, !exceptionVariant.includes(variant)), _cx3)),
    badgeContent: variant === 'error' ? /*#__PURE__*/React.createElement(Icon, {
      size: 16,
      className: cx(classes.errorIcon),
      icon: iconWarning
    }) : '',
    color: variant === 'error' ? 'error' : undefined,
    withBorder: false,
    size: "large",
    overlap: "rectangular",
    style: variant === 'shortcut' && !IconContent ? _defineProperty({}, 'background', nameToColor(name)) : null
  }, variant === 'shortcut' && !IconContent ? /*#__PURE__*/React.createElement(Typography, {
    className: classes.letter,
    variant: "h2",
    align: "center"
  }, letter.toUpperCase()) : /*#__PURE__*/React.createElement("div", {
    className: cx(styles['SquareAppIcon-icon-container'], _defineProperty({}, styles['SquareAppIcon-icon-container-normal'], themeVariant === 'normal'))
  }, /*#__PURE__*/React.createElement("div", {
    className: cx(styles['onEnd'], _defineProperty({}, styles['isSuccess'], animationState === 'success'), _defineProperty({}, styles['isFailed'], animationState === 'failed')),
    onAnimationEnd: handleAnimationEnd
  }, animationState && /*#__PURE__*/React.createElement(Icon, {
    size: 32,
    icon: animationState === 'success' ? IconCheckAnimated : SvgIconCrossAnimated
  })), variant === 'add' ? /*#__PURE__*/React.createElement(Icon, {
    icon: iconPlus,
    color: "var(--primaryColor)"
  }) : IconContent ? IconContent : /*#__PURE__*/React.createElement("div", {
    className: "u-w-2 u-h-2"
  }, /*#__PURE__*/React.createElement(AppIcon, appIconProps)))))), display === 'detailed' ? /*#__PURE__*/React.createElement(ListItemText, {
    primary: appName,
    secondary: description
  }) : /*#__PURE__*/React.createElement(Typography, {
    className: cx(classes.name, _defineProperty({}, classes.nameInverted, themeVariant === 'inverted'), 'u-spacellipsis'),
    variant: "h6",
    align: "center"
  }, appName));
};
/**
 * Having both a `display` and a `variant` prop is a bit confusing,
 * but it's necessary since the `variant` prop can be used both in "compact" and "detailed" mode.
 *
 * As for the `description` prop, it will only be displayed in "detailed" mode.
 * Providing it in "compact" mode will have no effect.
 */

SquareAppIcon.propTypes = {
  display: PropTypes.oneOf(['compact', 'detailed']),
  description: PropTypes.string,
  name: PropTypes.string,
  variant: PropTypes.oneOf(['default', 'loading', 'ghost', 'maintenance', 'error', 'add', 'shortcut']),
  IconContent: PropTypes.node
};
SquareAppIcon.defaultProps = {
  display: 'compact',
  variant: 'default'
};
export default SquareAppIcon;
